Networked chatroom-based coordination game
==========================================

This is a networked coordination game where players broadcast messages
to each other and try to make the same decision as others.


`Download the demo <../../_static/chatroom.zip>`__.
